@@ -16,7 +16,7 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 #
-# $Id: Detector.pm,v 1.22 2010/10/07 16:10:25 evertonm Exp $
+# $Id: Detector.pm,v 1.23 2010/12/02 19:38:29 evertonm Exp $
 
 package fetchconfig::model::Detector; # fetchconfig/model/Detector.pm
 
@@ -33,6 +33,7 @@ use fetchconfig::model::Dell;
 use fetchconfig::model::Terayon;
 use fetchconfig::model::DmSwitch;
 use fetchconfig::model::3ComMSR;
+use fetchconfig::model::MikroTik;
 
 my $logger;
 my %model_table;
@@ -194,6 +195,7 @@ sub init {
     $class->register(fetchconfig::model::Terayon->new($log));
     $class->register(fetchconfig::model::DmSwitch->new($log));
     $class->register(fetchconfig::model::3ComMSR->new($log));
+    $class->register(fetchconfig::model::MikroTik->new($log));
 }
 
 1;
